@@ -1,8 +1,4 @@
-from circle.resources.abstract import (
-    CreateableAPIResource,
-    ListableAPIResource,
-    RetrievableAPIResource,
-)
+from circle.resources.abstract import CreateableAPIResource, ListableAPIResource
 
 
 class Transfer(CreateableAPIResource, ListableAPIResource):
